bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 35. Aventiure
___________________________________________________ #### Auentv wie Irinch mit Hagenen streit #### vn– wie im sit an im gelanch
| ### <Do> rief von Tenemarche der marcgrave Irinch ### ich han vferelazen nv lange miniv dinch ### vn– han in volches stvermen des besten vil getan ### nv brinch mir min gewæfen ia wil ich Hagenen bestan ### Daz wil ich widerraten sprach do Hagene ### so gewinnent iwer mage mer ze klagene ### gespringent iwer zwene oder dri zvo mir her in ### ist daz si min erbitent si scheident schedeliche hin
###### 2086 | ### <Darvmbe> ihz niht enlaze sprach aber Irinch ### ich han ovch ê versvchet sam sorchlichiv dinc ### ia wil ich mit dem swerte aleine dich bestan ### ob dv mit strite hetest mer danne iemen getan
###### 2087 | ### Do wart gewafent Irinch nach <ritterlichem> sit ### alsam wart von Dvrigen der lantgrave Irnfrit ### vn– Hawart der starche wol mit tvsent man ### swes Irinch begvnde si woldens alle im gestan
| ### Do sach der videlære eine groze schar ### die mit Iringe gewafent chomen dar ### si trvgen vf gebvnden vil manigen helm gvot ### des wart der chvne Volker [75r]ein teil vil zornic gemvot
###### 2089 | ### Er sprach seht ir Hagene dort Iringen gan ### der ivch hie mit dem swerte lobt eine bestan ### wie zimt helede lvgene ich wil vnprisen daz ### ez gent mit im gewafent wol tvsent rechen oder baz
###### 2090 | ### Nv heizet mich niht liegen sprach Hawartes man ### ich wil ez leisten gerne swaz ich gelobet han ### dvrch deheine vorhte wil ihs abe gan ### wie vreislich nv si Hagene vzer Bvrgonden lant
###### 2091 | ### Doch bat er si so lange daz ez sit geschach ### do daz ingesinde den willen sin ersach ### daz er warp nach eren do liezen si in gan ### do wart ein grimmez striten von in beiden da getan
| ### Irinch der vil starche hohe erbvrt den ger ### den schilt er fvr sich zvchte der tivr degen her ### do lief vz zv Hagene vaste fvr den sal ### do hvop sich von den degenen ein vil grozlicher schal
###### 2093 | ### Do schvzzen si die gere mit chreften von der hant ### dvrch die vil vesten schilde vf liehtez ir gewant ### daz die gerstangen vil hohe dræten dan ### do griefen zv den swerten die vil grimme chvnen man
###### 2094 | ### Des starchen Hagenen ellen was in vnmazen groz ### ovch slvg vf <in> Irinch daz al div bvrch erdoz ### Palas vn– Tverne erhullen nach ir slegen ### done chunde niht verenden des sinen willen der degen
###### 2095 | ### Irinch lie do Hagenen vnverwndet stan ### zvo dem videlære gahen er began ### er wande in solde twingen mit den grimmen slegen ### sich chunde wol beschirmen der vil zierliche degen
###### 2096 | ### Do slvoc der videlære daz vber schildes rant ### dræte daz gespenge von Volkers hant ### den liez er do beliben ein was ein vbel man ### er lief den kunic Gvnther da von Buregonden an
###### 2097 | ### Do was ir ietwedere ze strite starch genvoc ### swaz Gunther on Irinch vf ein ander slvoch ### daz enbrahte niht von wnden dar vliezende blvot ### daz behvote ir gewæfen daz was veste vn– gvot
| ### Gvnthern er lie beliben Gernoten lief er an ### daz fivr vzen ringen er howen im began ### do hete von Bvregonden der starche Gernot ### den chvnen Iringin vil nach gesendet in den tot
###### 2099 | ### Do spranger von dem fvrsten snel er was genvoc ### der Bvrgonden viere der helt vil schiere slvoc ### des edeln ingesindes von Wormez vber Rin ### done chunde Giselhere zornær nimmer gesin
###### 2100 | ### Gote weiz her Irinch sprach Giselher daz kint ### ir mvzet mir die gelten die veige vor iv sint ### gelegen hie ze stvnden do lief er in an ### er slvoc den Tenemarche daz er strvchen began
###### 2101 | ### Er schoz vor sinen fvezen nider in daz blvot ### daz si alle wolden wænen daz der helt gvot ### ze strite nimmer mere geslvge cheinen slac ### Irinch noch ane wnden hie vor Giselhere lac [75v]
###### 2102 | ### Von des helmes doze vn– von des swertes chlanc ### wæren sine wizze worden also chranc ### daz sich der degen Irinch des lebenes niht versan ### daz het mit siner sterche der chvne Giselher getan
| ### Do im begunde wichen von hovbte der doz ### von helm vn– ovch von swerte der was gewesen groz ### er dahte ih bin noch lebnde min lip ist ninder wnt ### nv ist mir aller erste daz ellen Giselhers kvnt
###### 2104 | ### Do horter beidenhalben die viande stan ### heten siz gewisset im wære mer getan ### ovch het er Giselhere da bi im vernomen ### er dahte wie er solde mit dem libe dannen chomen
###### 2105 | ### Wie rehte tobeliche er vzem blvote spranch ### der siner snelheite er mohte <danch> ### do lief er vzem hvose da er aber Hagenen vant ### vn– slvg im slege swinde mit siner ellenthafter hant
###### 2106 | ### Do gedaht ovch Hagene dv solt der mine wesen ### dich enner der vbel tivfel dv enchanst nv niht genesen ### doch wndet Irinch Hagenen dvrch sinen helmhvot ### daz tet der helt mit Wasechen daz was ein wafen also gvot
###### 2107 | ### Do der grimme Hagene der wnden enpfant ### do erwaget im vngefvege daz swert an siner hant ### al da mvose im entwichen der Hawartes man ### zetal von dem hvse Hagen volgen im began
###### 2108 | ### Irinch vber hovbet den schilt vil balde swanc ### vn– wær div selbe stiege drier stiegen lanch ### done liez in Hagene slahen deheinen slac ### hey waz roter vanchen ob sime helme gelac
###### 2109 | ### Do sahen sine frivnde Iringen noch gesvnt ### do wrden disiv mære Chriemh' chvnt ### waz er dem von Tronege mit strite hete getan ### desim div chuniginne hohe danchen began
###### 2110 | ### Nv lone dir got Irinch vil mærrer helt gvot ### dv hast mir wol getrostet daz herce vn– ovch den mvot ### nv sihe ich Hagene rotez von blvte sin gewant ### do nam si im selbe den schilt vor liebe von der hant
###### 2111 | ### Ir mvgt im maze danchen sprach do Hagene ### ia ist noch harte chleine da von ze sagene ### vn– wolt erz noch versvchen so wær er chven ein man ### div wnde frvmt ivch chleine die ich von im gewnnen han
###### 2112 | ### Daz ir von miner wnden die ringe sehet rot ### daz hat mich erreizet vf maniges mannes tot ### ich bin alrerste erzvrnet vf in vn– manigen man ### mir hat der degen Irinch schaden chleinen noch getan
| ### Do stvnt gegen dem winde Irinch von Tenelant ### er chvlte sich in ringen den helm er abe gebant ### do sprachen al die lvte sin ellen wære gvot ### des het der marcgrave von schulden <hohen> mvot
###### 2114 | ### Irinch der vil chvene sinen frivnden sagte daz ### nv wafent mich vil balde ich wilz versvchen baz ### ob ich noch mvge betwingen den vbermveten [76r]man ### sin schilt der was verhowen einen bezzern er gewan
###### 2115 | ### Vil schiere wart der reche aber gewafent baz ### vn– einen ger vil starchen den nam er vf den haz ### daz er da mite Hagenen wolde noch bestan ### ez wær im frvom vn– ere ob erz hete nv verlan
###### 2116 | ### Sin mohte niht erbiten Hagene der degen ### do lief er im engegene mit stichen vn– mit slegen ### der stiege vnze an ein ende sin zvrnen daz was groz ### Irinch siner sterche harte wenic do genoz
###### 2117 | ### Si slvogen dvrch die schilde deiz lovgen began ### von vivr roten winden der Hawartes man ### wart von Hagenen swerte vil kreftiklichen wnt ### dvrch schilt vn– dvrch die brvenne des er wart nimmer mer gesvnt
| ### Do der degen Irinch der wnden enpfant ### den schilt er baz bedachte vber div helmbant ### des schaden in dvht der volle den er da gewan ### sit tet im noch mere der vil vbermvete man
###### 2119 | ### Hagen vor sinen fvzen einen ger er ligen vant ### do schoz er Iringen den helt von Tenelant ### daz im von dem hovbte der gere ragete dan ### im het der vbermvete den grimmen ende getan
###### 2120 | ### Irinch mvse wichen zv den von Tenelant ### e daz man do dem degene dem helm ab gebant ### den ger man brach von hbet do nahet im der tot ### daz weinten sine mage des gie in wærliche not
###### 2121 | ### Chriemh' div frowe chlagen ovch began ### den chvnen Iringen den schadehaften man ### si weinte sine wnden wande ez was ir leit ### do sprach vor sinen magen der snelle reche gemeit
###### 2122 | ### Lat iwer klage beliben vil herlichez wip ### waz hilfet iwer weinen ia mvoz <ich> minen lip ### verliesen von den wnden die ich enpfangen han ### der tot wil mich niht dienen iv vn– Ezeln lan
###### 2123 | ### Er sprach zv den von Dvrigen vnt den von Tenelant ### die gabe sol enpfahen iwer deheines hant ### von der kvniginne ir liehtez golt so rot ### vn– bestet ir Hagenen ir mvzet liden den tot
###### 2124 | ### Sin varwe was erblichen des todes zeichen trvoc ### Irinch der chvene daz was in leit genvoc ### genesen niht enchunde der Hawartes man ### do mvos ez an ein striten von den sinen frivnden gan
###### 2125 | ### Irnfrit vn– Hawart die sprvngen fvr daz gadem ### wol mit tvsent heleden vil vngefvgen chradem ### hort man allenthalben vil chreftechlichen groz ### hey waz man starcher gere vf die Bvrgonde schoz
###### 2126 | ### Irnvrit der herre lief an den spileman ### des er schaden grozen von siner hant gewan ### der chvene videlære den lantgraven slvoc ### dvrch einen helm vesten ia was er grimme genvoc
###### 2127 | ### Do slvoc der lantgrave den chvnen spileman ### daz im mvsen bresten ringes gespan [76v] ### vn– daz sich beschvtte div prvenne fivr rot ### do vil lantgrave vor dem vidælære tot
| ### Hawart vn– Hagene zesamne warn chomen ### er mohte wnder chiesen ders hete war genomen ### div swert genote vielen den rechen an der hant ### Hawart mvose ersterben von dem vz Bvrgonde lant
###### 2129 | ### Die Durigen vn– die Tenen ir herren sahen tot ### do hvop sich vor dem hvose ein vil grimmiv not ### ê si die tvr gewnnen mit ellenthafter hant ### des wart da verhowen vil manic helm vn– rant
###### 2130 | ### Wichet sprach do Volker lat si her in gan ### ez ist svs vnverendet des si da habent wan ### si mvzen drinne ersterben in vil chvrcer zit ### si arnent mit dem tode daz in div kvniginne git
###### 2131 | ### Do die vbermveten chomen in den sal ### manigem wart daz hovbet geneiget so zetal ### daz er mvse ersterben von ir grimmen slegen ### wol streit der chvne Gernot sam tet ovch Giselher der degen
| ### Tvsent vn– viere die chomen dar in ### die erzeigten drinne schiere ir degenlichen sin ### si wrden von den gesten alle zehant erslagen ### man mohte michel wnder von den Burgonden sagen
###### 2133 | ### Dar nach wart ein stille daz der schal verdoz ### daz blvot do allenthalben dvrch div locher vloz ### vn– da zen rigelsteinen von den chvnen man ### daz heten die von Rine mit grozem ellen getan
###### 2134 | ### Do sazen aber rvowen die chomen in daz lant ### ir schilde vnt wafen si leiten von der hant ### do stvnt noch vor dem hvose der chvne spileman ### ob iemen zvo zin wolde mit strite zvo dem sale gan
###### 2135 | ### Der chvnic klagte sere sam tet ovch sin wip ### mægde vn– frowen die qvelten ovch den lip ### ich wæne des daz hete der tot vf si gesworn ### des wart noch vil der degene von den gesten verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>